multidim.models.CDER.fit — GDA Toolbox v1.0 Manual

# multidim.models.CDER.fit

`CDER.` `fit`(*training)

  Fit this estimator to training data. This is the step that runs the actual predictor.

  Parameters: | *training Can be any of the following: a pair of list-like objects: pointclouds_train and labels_train The items in pointclouds_train should be `numpy.ndarray` objects. The items in labels_train should be strings (preferably, color names). a single labelled and weighted `multidim.PointCloud` a single `multidim.covertree.CoverTree` obtained from a labelled and weighted `multidim.PointCloud`

#### Previous topic

multidim.models.CDER.evaluate

#### Next topic

multidim.models.CDER.gausscoords